@@ -1,4 +1,4 @@
-"""A Python module for iteracting with Slack's Web API."""
+"""A Python module for interacting with Slack's Web API."""
 
 # Standard Imports
 from typing import Union, List
@@ -81,8 +81,6 @@ class WebClient(BaseClient):
         Raises:
             SlackRequestError: If niether or both the `app_id` and `request_id` args are specified.
         """
-        self._validate_xoxp_token()
-
         if app_id:
             kwargs.update({"app_id": app_id})
         elif request_id:
@@ -96,12 +94,10 @@ class WebClient(BaseClient):
 
     def admin_apps_requests_list(self, **kwargs) -> Union[Future, SlackResponse]:
         """List app requests for a team/workspace."""
-        self._validate_xoxp_token()
         return self.api_call("admin.apps.requests.list", http_verb="GET", params=kwargs)
 
     def admin_apps_restrict(self, **kwargs) -> Union[Future, SlackResponse]:
         """Restrict an app for installation on a workspace."""
-        self._validate_xoxp_token()
         return self.api_call("admin.apps.restrict", json=kwargs)
 
     def admin_users_session_reset(
@@ -112,10 +108,199 @@ class WebClient(BaseClient):
         Args:
             user_id (str): The ID of the user to wipe sessions for. e.g. 'W12345678'
         """
-        self._validate_xoxp_token()
         kwargs.update({"user_id": user_id})
         return self.api_call("admin.users.session.reset", json=kwargs)
 
+    def admin_inviteRequests_approve(
+        self, *, invite_request_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Approve a workspace invite request.
+
+        team_id is required if your Enterprise Grid org contains more than one workspace.
+
+        Args:
+            invite_request_id (str): ID of the request to invite. e.g. 'Ir1234'
+        """
+        kwargs.update({"invite_request_id": invite_request_id})
+        return self.api_call("admin.inviteRequests.approve", json=kwargs)
+
+    def admin_inviteRequests_approved_list(
+        self, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """List all approved workspace invite requests."""
+        return self.api_call("admin.inviteRequests.approved.list", json=kwargs)
+
+    def admin_inviteRequests_denied_list(
+        self, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """List all denied workspace invite requests."""
+        return self.api_call("admin.inviteRequests.denied.list", json=kwargs)
+
+    def admin_inviteRequests_deny(
+        self, *, invite_request_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Deny a workspace invite request.
+
+        Args:
+            invite_request_id (str): ID of the request to invite. e.g. 'Ir1234'
+        """
+        kwargs.update({"invite_request_id": invite_request_id})
+        return self.api_call("admin.inviteRequests.deny", json=kwargs)
+
+    def admin_inviteRequests_list(self, **kwargs) -> Union[Future, SlackResponse]:
+        """List all pending workspace invite requests."""
+        return self.api_call("admin.inviteRequests.list", json=kwargs)
+
+    def admin_teams_admins_list(
+        self, *, team_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """List all of the admins on a given workspace.
+
+        Args:
+            team_id (str): ID of the team.
+        """
+        kwargs.update({"team_id": team_id})
+        return self.api_call("admin.teams.admins.list", http_verb="GET", params=kwargs)
+
+    def admin_teams_create(
+        self, *, team_domain: str, team_name: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Create an Enterprise team.
+
+        Args:
+            team_domain (str): Team domain. e.g. 'slacksoftballteam'
+            team_name (str): Team name. e.g. 'Slack Softball Team'
+        """
+        kwargs.update({"team_domain": team_domain, "team_name": team_name})
+        return self.api_call("admin.teams.create", json=kwargs)
+
+    def admin_teams_list(self, **kwargs) -> Union[Future, SlackResponse]:
+        """List all teams on an Enterprise organization."""
+        return self.api_call("admin.teams.list", json=kwargs)
+
+    def admin_teams_owners_list(
+        self, *, team_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """List all of the admins on a given workspace.
+
+        Args:
+            team_id (str): ID of the team.
+        """
+        kwargs.update({"team_id": team_id})
+        return self.api_call("admin.teams.owners.list", http_verb="GET", params=kwargs)
+
+    def admin_teams_settings_setDescription(
+        self, *, team_id: str, description: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set the description of a given workspace.
+
+        Args:
+            team_id (str): ID of the team.
+            description (str): Description of the team.
+        """
+        kwargs.update({"team_id": team_id, "description": description})
+        return self.api_call("admin.teams.settings.setDescription", json=kwargs)
+
+    def admin_teams_settings_setIcon(
+        self, *, team_id: str, image_url: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Sets the icon of a workspace.
+
+        Args:
+            team_id (str): ID of the team.
+            image_url (str): Url of the icon.
+        """
+        kwargs.update({"team_id": team_id, "image_url": image_url})
+        return self.api_call(
+            "admin.teams.settings.setIcon", http_verb="GET", params=kwargs
+        )
+
+    def admin_teams_settings_setName(
+        self, *, team_id: str, name: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Sets the icon of a workspace.
+
+        Args:
+            team_id (str): ID of the team.
+            name (str): Name of the team.
+        """
+        kwargs.update({"team_id": team_id, "name": name})
+        return self.api_call("admin.teams.settings.setName", json=kwargs)
+
+    def admin_users_assign(
+        self, *, team_id: str, user_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Add an Enterprise user to a workspace.
+
+        Args:
+            team_id (str): ID of the team. e.g. 'T1234'
+            user_id (str): ID of the user to add to the workspace.
+        """
+        kwargs.update({"team_id": team_id, "user_id": user_id})
+        return self.api_call("admin.users.assign", json=kwargs)
+
+    def admin_users_invite(
+        self, *, team_id: str, email: str, channel_ids: List[str], **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Invite a user to a workspace.
+
+        Args:
+            team_id (str): ID of the team. e.g. 'T1234'
+            email (str): The email address of the person to invite. e.g. 'joe@email.com'
+            channel_ids (list): A list of channel_ids for this user to join.
+                At least one channel is required. e.g. ['C1A2B3C4D', 'C26Z25Y24']
+        """
+        kwargs.update({"team_id": team_id, "email": email, "channel_ids": channel_ids})
+        return self.api_call("admin.users.invite", json=kwargs)
+
+    def admin_users_remove(
+        self, *, team_id: str, user_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Remove a user from a workspace.
+
+        Args:
+            team_id (str): ID of the team. e.g. 'T1234'
+            user_id (str): The ID of the user to remove. e.g. 'W12345678'
+        """
+        kwargs.update({"team_id": team_id, "user_id": user_id})
+        return self.api_call("admin.users.remove", json=kwargs)
+
+    def admin_users_setAdmin(
+        self, *, team_id: str, user_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set an existing guest, regular user, or owner to be an admin user.
+
+        Args:
+            team_id (str): ID of the team. e.g. 'T1234'
+            user_id (str): The ID of the user to remove. e.g. 'W12345678'
+        """
+        kwargs.update({"team_id": team_id, "user_id": user_id})
+        return self.api_call("admin.users.setAdmin", json=kwargs)
+
+    def admin_users_setOwner(
+        self, *, team_id: str, user_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set an existing guest, regular user, or admin user to be a workspace owner.
+
+        Args:
+            team_id (str): ID of the team. e.g. 'T1234'
+            user_id (str): The ID of the user to remove. e.g. 'W12345678'
+        """
+        kwargs.update({"team_id": team_id, "user_id": user_id})
+        return self.api_call("admin.users.setOwner", json=kwargs)
+
+    def admin_users_setRegular(
+        self, *, team_id: str, user_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set an existing guest user, admin user, or owner to be a regular user.
+
+        Args:
+            team_id (str): ID of the team. e.g. 'T1234'
+            user_id (str): The ID of the user to remove. e.g. 'W12345678'
+        """
+        kwargs.update({"team_id": team_id, "user_id": user_id})
+        return self.api_call("admin.users.setRegular", json=kwargs)
+
     def api_test(self, **kwargs) -> Union[Future, SlackResponse]:
         """Checks API calling code."""
         return self.api_call("api.test", json=kwargs)
@@ -140,7 +325,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("channels.archive", json=kwargs)
 
@@ -150,7 +334,6 @@ class WebClient(BaseClient):
         Args:
             name (str): The name of the channel. e.g. 'mychannel'
         """
-        self._validate_xoxp_token()
         kwargs.update({"name": name})
         return self.api_call("channels.create", json=kwargs)
 
@@ -183,7 +366,6 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             user (str): The user id. e.g. 'U1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "user": user})
         return self.api_call("channels.invite", json=kwargs)
 
@@ -193,7 +375,6 @@ class WebClient(BaseClient):
         Args:
             name (str): The channel name. e.g. '#general'
         """
-        self._validate_xoxp_token()
         kwargs.update({"name": name})
         return self.api_call("channels.join", json=kwargs)
 
@@ -206,7 +387,6 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             user (str): The user id. e.g. 'U1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "user": user})
         return self.api_call("channels.kick", json=kwargs)
 
@@ -216,7 +396,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("channels.leave", json=kwargs)
 
@@ -245,7 +424,6 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             name (str): The new channel name. e.g. 'newchannel'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "name": name})
         return self.api_call("channels.rename", json=kwargs)
 
@@ -294,7 +472,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("channels.unarchive", json=kwargs)
 
@@ -405,7 +582,6 @@ class WebClient(BaseClient):
             unfurls (dict): a dict of the specific URLs you're offering an unfurl for.
                 e.g. {"https://example.com/": {"text": "Every day is the test."}}
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "ts": ts, "unfurls": unfurls})
         return self.api_call("chat.unfurl", json=kwargs)
 
@@ -438,7 +614,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("conversations.archive", json=kwargs)
 
@@ -461,7 +636,6 @@ class WebClient(BaseClient):
         Args:
             name (str): The name of the channel. e.g. 'mychannel'
         """
-        self._validate_xoxp_token()
         kwargs.update({"name": name})
         return self.api_call("conversations.create", json=kwargs)
 
@@ -496,7 +670,6 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             users (list): An list of user id's to invite. e.g. ['U2345678901', 'U3456789012']
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "users": users})
         return self.api_call("conversations.invite", json=kwargs)
 
@@ -508,7 +681,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("conversations.join", json=kwargs)
 
@@ -521,7 +693,6 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             user (str): The id of the user to kick. e.g. 'U2345678901'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "user": user})
         return self.api_call("conversations.kick", json=kwargs)
 
@@ -533,7 +704,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("conversations.leave", json=kwargs)
 
@@ -565,7 +735,6 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             name (str): The new channel name. e.g. 'newchannel'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "name": name})
         return self.api_call("conversations.rename", json=kwargs)
 
@@ -613,7 +782,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("conversations.unarchive", json=kwargs)
 
@@ -650,12 +818,10 @@ class WebClient(BaseClient):
 
     def dnd_endDnd(self, **kwargs) -> Union[Future, SlackResponse]:
         """Ends the current user's Do Not Disturb session immediately."""
-        self._validate_xoxp_token()
         return self.api_call("dnd.endDnd", json=kwargs)
 
     def dnd_endSnooze(self, **kwargs) -> Union[Future, SlackResponse]:
         """Ends the current user's snooze mode immediately."""
-        self._validate_xoxp_token()
         return self.api_call("dnd.endSnooze", json=kwargs)
 
     def dnd_info(self, **kwargs) -> Union[Future, SlackResponse]:
@@ -670,7 +836,6 @@ class WebClient(BaseClient):
         Args:
             num_minutes (int): The snooze duration. e.g. 60
         """
-        self._validate_xoxp_token()
         kwargs.update({"num_minutes": num_minutes})
         return self.api_call("dnd.setSnooze", http_verb="GET", params=kwargs)
 
@@ -714,7 +879,6 @@ class WebClient(BaseClient):
 
     def files_list(self, **kwargs) -> Union[Future, SlackResponse]:
         """Lists & filters team files."""
-        self._validate_xoxp_token()
         return self.api_call("files.list", http_verb="GET", params=kwargs)
 
     def files_remote_info(self, **kwargs) -> Union[Future, SlackResponse]:
@@ -768,7 +932,6 @@ class WebClient(BaseClient):
         Args:
             file (str): The file id. e.g. 'F1234467890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"file": file})
         return self.api_call("files.revokePublicURL", json=kwargs)
 
@@ -780,7 +943,6 @@ class WebClient(BaseClient):
         Args:
             file (str): The file id. e.g. 'F1234467890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"file": file})
         return self.api_call("files.sharedPublicURL", json=kwargs)
 
@@ -816,7 +978,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'C1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("groups.archive", json=kwargs)
 
@@ -826,7 +987,6 @@ class WebClient(BaseClient):
         Args:
             name (str): The name of the private group. e.g. 'mychannel'
         """
-        self._validate_xoxp_token()
         kwargs.update({"name": name})
         return self.api_call("groups.create", json=kwargs)
 
@@ -838,7 +998,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The group id. e.g. 'G1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("groups.createChild", http_verb="GET", params=kwargs)
 
@@ -869,7 +1028,6 @@ class WebClient(BaseClient):
             channel (str): The group id. e.g. 'G1234567890'
             user (str): The user id. e.g. 'U1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "user": user})
         return self.api_call("groups.invite", json=kwargs)
 
@@ -882,7 +1040,6 @@ class WebClient(BaseClient):
             channel (str): The group id. e.g. 'G1234567890'
             user (str): The user id. e.g. 'U1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "user": user})
         return self.api_call("groups.kick", json=kwargs)
 
@@ -892,7 +1049,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The group id. e.g. 'G1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("groups.leave", json=kwargs)
 
@@ -930,7 +1086,6 @@ class WebClient(BaseClient):
             channel (str): The channel id. e.g. 'C1234567890'
             name (str): The new channel name. e.g. 'newchannel'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "name": name})
         return self.api_call("groups.rename", json=kwargs)
 
@@ -944,7 +1099,6 @@ class WebClient(BaseClient):
             thread_ts (str): The timestamp of an existing message with 0 or more replies.
                 e.g. '1234567890.123456'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel, "thread_ts": thread_ts})
         return self.api_call("groups.replies", http_verb="GET", params=kwargs)
 
@@ -980,7 +1134,6 @@ class WebClient(BaseClient):
         Args:
             channel (str): The channel id. e.g. 'G1234567890'
         """
-        self._validate_xoxp_token()
         kwargs.update({"channel": channel})
         return self.api_call("groups.unarchive", json=kwargs)
 
@@ -1205,7 +1358,6 @@ class WebClient(BaseClient):
                 the number of seconds until the reminder (if within 24 hours),
                 or a natural language description (Ex. 'in 15 minutes' or 'every Thursday')
         """
-        self._validate_xoxp_token()
         kwargs.update({"text": text, "time": time})
         return self.api_call("reminders.add", json=kwargs)
 
@@ -1218,7 +1370,6 @@ class WebClient(BaseClient):
             reminder (str): The ID of the reminder to be marked as complete.
                 e.g. 'Rm12345678'
         """
-        self._validate_xoxp_token()
         kwargs.update({"reminder": reminder})
         return self.api_call("reminders.complete", json=kwargs)
 
@@ -1230,7 +1381,6 @@ class WebClient(BaseClient):
         Args:
             reminder (str): The ID of the reminder. e.g. 'Rm12345678'
         """
-        self._validate_xoxp_token()
         kwargs.update({"reminder": reminder})
         return self.api_call("reminders.delete", json=kwargs)
 
@@ -1242,13 +1392,11 @@ class WebClient(BaseClient):
         Args:
             reminder (str): The ID of the reminder. e.g. 'Rm12345678'
         """
-        self._validate_xoxp_token()
         kwargs.update({"reminder": reminder})
         return self.api_call("reminders.info", http_verb="GET", params=kwargs)
 
     def reminders_list(self, **kwargs) -> Union[Future, SlackResponse]:
         """Lists all reminders created by or for a given user."""
-        self._validate_xoxp_token()
         return self.api_call("reminders.list", http_verb="GET", params=kwargs)
 
     def rtm_connect(self, **kwargs) -> Union[Future, SlackResponse]:
@@ -1266,7 +1414,6 @@ class WebClient(BaseClient):
             query (str): Search query. May contains booleans, etc.
                 e.g. 'pickleface'
         """
-        self._validate_xoxp_token()
         kwargs.update({"query": query})
         return self.api_call("search.all", http_verb="GET", params=kwargs)
 
@@ -1277,7 +1424,6 @@ class WebClient(BaseClient):
             query (str): Search query. May contains booleans, etc.
                 e.g. 'pickleface'
         """
-        self._validate_xoxp_token()
         kwargs.update({"query": query})
         return self.api_call("search.files", http_verb="GET", params=kwargs)
 
@@ -1288,7 +1434,6 @@ class WebClient(BaseClient):
             query (str): Search query. May contains booleans, etc.
                 e.g. 'pickleface'
         """
-        self._validate_xoxp_token()
         kwargs.update({"query": query})
         return self.api_call("search.messages", http_verb="GET", params=kwargs)
 
@@ -1306,7 +1451,6 @@ class WebClient(BaseClient):
 
     def stars_list(self, **kwargs) -> Union[Future, SlackResponse]:
         """Lists stars for a user."""
-        self._validate_xoxp_token()
         return self.api_call("stars.list", http_verb="GET", params=kwargs)
 
     def stars_remove(self, **kwargs) -> Union[Future, SlackResponse]:
@@ -1323,12 +1467,10 @@ class WebClient(BaseClient):
 
     def team_accessLogs(self, **kwargs) -> Union[Future, SlackResponse]:
         """Gets the access logs for the current team."""
-        self._validate_xoxp_token()
         return self.api_call("team.accessLogs", http_verb="GET", params=kwargs)
 
     def team_billableInfo(self, **kwargs) -> Union[Future, SlackResponse]:
         """Gets billable users information for the current team."""
-        self._validate_xoxp_token()
         return self.api_call("team.billableInfo", http_verb="GET", params=kwargs)
 
     def team_info(self, **kwargs) -> Union[Future, SlackResponse]:
@@ -1337,12 +1479,10 @@ class WebClient(BaseClient):
 
     def team_integrationLogs(self, **kwargs) -> Union[Future, SlackResponse]:
         """Gets the integration logs for the current team."""
-        self._validate_xoxp_token()
         return self.api_call("team.integrationLogs", http_verb="GET", params=kwargs)
 
     def team_profile_get(self, **kwargs) -> Union[Future, SlackResponse]:
         """Retrieve a team's profile."""
-        self._validate_xoxp_token()
         return self.api_call("team.profile.get", http_verb="GET", params=kwargs)
 
     def usergroups_create(self, *, name: str, **kwargs) -> Union[Future, SlackResponse]:
@@ -1352,7 +1492,6 @@ class WebClient(BaseClient):
             name (str): A name for the User Group. Must be unique among User Groups.
                 e.g. 'My Test Team'
         """
-        self._validate_xoxp_token()
         kwargs.update({"name": name})
         return self.api_call("usergroups.create", json=kwargs)
 
@@ -1365,7 +1504,6 @@ class WebClient(BaseClient):
             usergroup (str): The encoded ID of the User Group to disable.
                 e.g. 'S0604QSJC'
         """
-        self._validate_xoxp_token()
         kwargs.update({"usergroup": usergroup})
         return self.api_call("usergroups.disable", json=kwargs)
 
@@ -1378,13 +1516,11 @@ class WebClient(BaseClient):
             usergroup (str): The encoded ID of the User Group to enable.
                 e.g. 'S0604QSJC'
         """
-        self._validate_xoxp_token()
         kwargs.update({"usergroup": usergroup})
         return self.api_call("usergroups.enable", json=kwargs)
 
     def usergroups_list(self, **kwargs) -> Union[Future, SlackResponse]:
         """List all User Groups for a team"""
-        self._validate_xoxp_token()
         return self.api_call("usergroups.list", http_verb="GET", params=kwargs)
 
     def usergroups_update(
@@ -1396,7 +1532,6 @@ class WebClient(BaseClient):
             usergroup (str): The encoded ID of the User Group to update.
                 e.g. 'S0604QSJC'
         """
-        self._validate_xoxp_token()
         kwargs.update({"usergroup": usergroup})
         return self.api_call("usergroups.update", json=kwargs)
 
@@ -1409,7 +1544,6 @@ class WebClient(BaseClient):
             usergroup (str): The encoded ID of the User Group to update.
                 e.g. 'S0604QSJC'
         """
-        self._validate_xoxp_token()
         kwargs.update({"usergroup": usergroup})
         return self.api_call("usergroups.users.list", http_verb="GET", params=kwargs)
 
@@ -1424,7 +1558,6 @@ class WebClient(BaseClient):
             users (list): A list user IDs that represent the entire list of
                 users for the User Group. e.g. ['U060R4BJ4', 'U060RNRCZ']
         """
-        self._validate_xoxp_token()
         kwargs.update({"usergroup": usergroup, "users": users})
         return self.api_call("usergroups.users.update", json=kwargs)
 
@@ -1434,7 +1567,6 @@ class WebClient(BaseClient):
 
     def users_deletePhoto(self, **kwargs) -> Union[Future, SlackResponse]:
         """Delete the user profile photo"""
-        self._validate_xoxp_token()
         return self.api_call("users.deletePhoto", http_verb="GET", params=kwargs)
 
     def users_getPresence(self, *, user: str, **kwargs) -> Union[Future, SlackResponse]:
@@ -1449,7 +1581,6 @@ class WebClient(BaseClient):
 
     def users_identity(self, **kwargs) -> Union[Future, SlackResponse]:
         """Get a user's identity."""
-        self._validate_xoxp_token()
         return self.api_call("users.identity", http_verb="GET", params=kwargs)
 
     def users_info(self, *, user: str, **kwargs) -> Union[Future, SlackResponse]:
@@ -1487,7 +1618,6 @@ class WebClient(BaseClient):
             image (str): Supply the path of the image you'd like to upload.
                 e.g. 'myimage.png'
         """
-        self._validate_xoxp_token()
         return self.api_call("users.setPhoto", files={"image": image}, data=kwargs)
 
     def users_setPresence(
@@ -1503,12 +1633,10 @@ class WebClient(BaseClient):
 
     def users_profile_get(self, **kwargs) -> Union[Future, SlackResponse]:
         """Retrieves a user's profile information."""
-        self._validate_xoxp_token()
         return self.api_call("users.profile.get", http_verb="GET", params=kwargs)
 
     def users_profile_set(self, **kwargs) -> Union[Future, SlackResponse]:
         """Set the profile information for a user."""
-        self._validate_xoxp_token()
         return self.api_call("users.profile.set", json=kwargs)
 
     def views_open(
